# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: sandbox.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'sandbox.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rsandbox.proto\x12\x07sandbox\"b\n\x0cStartRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x03 \x03(\t\x12\x11\n\tmemory_mb\x18\x04 \x01(\x03\x12\x11\n\tcpu_cores\x18\x05 \x01(\x01\"\x1b\n\rStartResponse\x12\n\n\x02id\x18\x01 \x01(\t\"/\n\x0bStopRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0cskip_cleanup\x18\x02 \x01(\x08\"\x0e\n\x0cStopResponse\"*\n\x0b\x45xecRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x02 \x03(\t\"A\n\x0c\x45xecResponse\x12\x0e\n\x06stdout\x18\x01 \x01(\t\x12\x0e\n\x06stderr\x18\x02 \x01(\t\x12\x11\n\texit_code\x18\x03 \x01(\x05\"\x1b\n\rStatusRequest\x12\n\n\x02id\x18\x01 \x01(\t\",\n\x0eStatusResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\"\x1c\n\x0eMetricsRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\xed\x01\n\x0fMetricsResponse\x12\x1a\n\x12memory_usage_bytes\x18\x01 \x01(\x04\x12\x1a\n\x12memory_limit_bytes\x18\x02 \x01(\x04\x12\x16\n\x0ememory_percent\x18\x03 \x01(\x01\x12\x13\n\x0b\x63pu_percent\x18\x04 \x01(\x01\x12\x14\n\x0cpids_current\x18\x05 \x01(\x04\x12\x14\n\x0cnet_rx_bytes\x18\x06 \x01(\x04\x12\x14\n\x0cnet_tx_bytes\x18\x07 \x01(\x04\x12\x18\n\x10\x62lock_read_bytes\x18\x08 \x01(\x04\x12\x19\n\x11\x62lock_write_bytes\x18\t \x01(\x04\"\x1d\n\x0fSnapshotRequest\x12\n\n\x02id\x18\x01 \x01(\t\"@\n\x10SnapshotResponse\x12\x15\n\rsnapshot_path\x18\x01 \x01(\t\x12\x15\n\rmem_file_path\x18\x02 \x01(\t\"\x1b\n\rResumeRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x10\n\x0eResumeResponse\",\n\x10RunPythonRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\"#\n\x11RunPythonResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"$\n\x16GetPlatformInfoRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\'\n\x17GetPlatformInfoResponse\x12\x0c\n\x04info\x18\x01 \x01(\t2\xea\x04\n\x0eSandboxService\x12=\n\x0cStartSandbox\x12\x15.sandbox.StartRequest\x1a\x16.sandbox.StartResponse\x12:\n\x0bStopSandbox\x12\x14.sandbox.StopRequest\x1a\x15.sandbox.StopResponse\x12:\n\x0b\x45xecCommand\x12\x14.sandbox.ExecRequest\x1a\x15.sandbox.ExecResponse\x12<\n\tGetStatus\x12\x16.sandbox.StatusRequest\x1a\x17.sandbox.StatusResponse\x12?\n\nGetMetrics\x12\x17.sandbox.MetricsRequest\x1a\x18.sandbox.MetricsResponse\x12\x46\n\x0fSnapshotSandbox\x12\x18.sandbox.SnapshotRequest\x1a\x19.sandbox.SnapshotResponse\x12@\n\rResumeSandbox\x12\x16.sandbox.ResumeRequest\x1a\x17.sandbox.ResumeResponse\x12\x42\n\tRunPython\x12\x19.sandbox.RunPythonRequest\x1a\x1a.sandbox.RunPythonResponse\x12T\n\x0fGetPlatformInfo\x12\x1f.sandbox.GetPlatformInfoRequest\x1a .sandbox.GetPlatformInfoResponseB1Z/github.com/agent-sandbox/orchestrator/api/protob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sandbox_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/agent-sandbox/orchestrator/api/proto'
  _globals['_STARTREQUEST']._serialized_start=26
  _globals['_STARTREQUEST']._serialized_end=124
  _globals['_STARTRESPONSE']._serialized_start=126
  _globals['_STARTRESPONSE']._serialized_end=153
  _globals['_STOPREQUEST']._serialized_start=155
  _globals['_STOPREQUEST']._serialized_end=202
  _globals['_STOPRESPONSE']._serialized_start=204
  _globals['_STOPRESPONSE']._serialized_end=218
  _globals['_EXECREQUEST']._serialized_start=220
  _globals['_EXECREQUEST']._serialized_end=262
  _globals['_EXECRESPONSE']._serialized_start=264
  _globals['_EXECRESPONSE']._serialized_end=329
  _globals['_STATUSREQUEST']._serialized_start=331
  _globals['_STATUSREQUEST']._serialized_end=358
  _globals['_STATUSRESPONSE']._serialized_start=360
  _globals['_STATUSRESPONSE']._serialized_end=404
  _globals['_METRICSREQUEST']._serialized_start=406
  _globals['_METRICSREQUEST']._serialized_end=434
  _globals['_METRICSRESPONSE']._serialized_start=437
  _globals['_METRICSRESPONSE']._serialized_end=674
  _globals['_SNAPSHOTREQUEST']._serialized_start=676
  _globals['_SNAPSHOTREQUEST']._serialized_end=705
  _globals['_SNAPSHOTRESPONSE']._serialized_start=707
  _globals['_SNAPSHOTRESPONSE']._serialized_end=771
  _globals['_RESUMEREQUEST']._serialized_start=773
  _globals['_RESUMEREQUEST']._serialized_end=800
  _globals['_RESUMERESPONSE']._serialized_start=802
  _globals['_RESUMERESPONSE']._serialized_end=818
  _globals['_RUNPYTHONREQUEST']._serialized_start=820
  _globals['_RUNPYTHONREQUEST']._serialized_end=864
  _globals['_RUNPYTHONRESPONSE']._serialized_start=866
  _globals['_RUNPYTHONRESPONSE']._serialized_end=901
  _globals['_GETPLATFORMINFOREQUEST']._serialized_start=903
  _globals['_GETPLATFORMINFOREQUEST']._serialized_end=939
  _globals['_GETPLATFORMINFORESPONSE']._serialized_start=941
  _globals['_GETPLATFORMINFORESPONSE']._serialized_end=980
  _globals['_SANDBOXSERVICE']._serialized_start=983
  _globals['_SANDBOXSERVICE']._serialized_end=1601
# @@protoc_insertion_point(module_scope)
